
Development
====================

The source of |managesieve| is maintained at
`GitLab <https://gitlab.com>`_.
Patches and pull-requests are hearty welcome.

* Please submit bugs and enhancements to the `Issue Tracker
  <https://gitlab.com/htgoebel/managesieve/issues>`_.

* You may browse the code at the
  `Repository Browser
  <https://gitlab.com/htgoebel/managesieve>`_
  Or you may check out the current version by running ::

    git clone https://gitlab.com/htgoebel/managesieve.git



*Historical Note:*
|managesieve| was hosted at origo.ethz.ch, which closed in May 2012.
Then |managesieve| was hosted on gitorious.org,
which was closed in May 2015 and merged into gitlab.

.. include:: _common_definitions.txt
